==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScalerParams } from "./ScalerParams";
import { PathGeometry } from "igniteui-react-core";
import { Numeric } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterSplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSplineSeries, _super);
    function ScatterSplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSplineSeries.$;
        _this.yx = new ScatterFrame();
        _this.yz = new ScatterFrame();
        _this.yv = new ScatterFrame();
        return _this;
    }
    ScatterSplineSeries.prototype.bj = function () {
        return new ScatterSplineSeries();
    };
    ScatterSplineSeries.prototype.get_fz = function () {
        return true;
    };
    ScatterSplineSeries.prototype.cr = function () {
        return new ScatterSplineSeriesView(this);
    };
    ScatterSplineSeries.prototype.zr = function () {
        return true;
    };
    ScatterSplineSeries.prototype.jj = function () {
        if (!isNaN_(this.ji)) {
            return _super.prototype.jj.call(this);
        }
        return Defaults.x;
    };
    ScatterSplineSeries.prototype.q7 = function (a, b, c, d) {
        _super.prototype.q7.call(this, a, b, c, d);
        switch (b) {
            case ScatterSplineSeries.$$p[0]:
                this.rp(false);
                this.qj();
                break;
        }
    };
    ScatterSplineSeries.prototype.b1 = function () {
        if (this.b2 == 0) {
            return 2;
        }
        else {
            return _super.prototype.b1.call(this);
        }
    };
    ScatterSplineSeries.prototype.aba = function (a, b) {
        var _this = this;
        _super.prototype.aba.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = this.ic * this.ic;
        var g = Math.min(this.zc != null ? this.zc.count : 0, this.zd != null ? this.zd.count : 0);
        var h = new ScalerParams(0, c, d, this.yr.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.yr.e, e);
            $ret.b = _this.ix();
            return $ret;
        })());
        var j = function (k) { return _this.yr.a.ek(_this.zc.item(k), h); };
        var k = function (l) { return _this.yr.b.ek(_this.zd.item(l), i); };
        var l = ((function () {
            var $ret = new Clipper(0, d, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var m = 0; m < g;) {
            var n = m;
            ++m;
            while (m < g && this.aci(j, k, n, m) < f) {
                ++m;
            }
            if (g > this.z4) {
                l.j(this.acm(j, k, n, m - 1));
            }
            else {
                var o = new OwnedPoint();
                o.c = { $type: Point_$type, x: j(n), y: k(n) };
                o.a = this.dm.item(n);
                if (!a.u.containsKey(o.a)) {
                    a.u.addItem(o.a, o);
                }
            }
        }
        if (g > this.z4) {
            l.i = null;
        }
    };
    ScatterSplineSeries.prototype.acm = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a(c), y: b(c) };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a(h);
            f += b(h);
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterSplineSeries.prototype.aci = function (a, b, c, d) {
        var e = a(d) - a(c);
        var f = b(d) - b(c);
        return e * e + f * f;
    };
    ScatterSplineSeries.prototype.get_zl = function () {
        return true;
    };
    ScatterSplineSeries.prototype.o4 = function (a, b) {
        _super.prototype.o4.call(this, a, b);
        var c = typeCast(ScatterSplineSeriesView.$, b);
        c.c9(false);
    };
    ScatterSplineSeries.prototype.abl = function (a, b) {
        this.o4(false, b);
        _super.prototype.abl.call(this, a, b);
        this.abd(a);
        var c = typeCast(ScatterSplineSeriesView.$, b);
        var d = c.dl;
        this.y4.az(this, this.zq(), runOn(this, this.yk));
        var e = false;
        var f = this.y4.b;
        if (f != null) {
            e = true;
        }
        if (e) {
            this.aa6(-1, this.zc.count, b.q);
        }
        this.y4.ad(d, true, false, true, false);
        c.dl.an = new PathGeometry();
        c.dl.an.c = Numeric.h(a.m.count, function (g) { return a.m._inner[g].x; }, function (g) { return a.m._inner[g].y; }, this.acj);
    };
    ScatterSplineSeries.$t = markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:acj:acl', [1, 0.5]]);
    return ScatterSplineSeries;
}(ScatterBase));
export { ScatterSplineSeries };

==> igniteui-react-charts-18.7.5-beta.0.tgz: package/esm5/lib/ScatterSplineSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { DependencyProperty } from "igniteui-react-core";
import { Point_$type, typeCast, runOn, markType, markDep } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterSplineSeriesView } from "./ScatterSplineSeriesView";
import { Defaults } from "./Defaults";
import { Clipper } from "igniteui-react-core";
import { OwnedPoint } from "./OwnedPoint";
import { ScalerParams } from "./ScalerParams";
import { PathGeometry } from "igniteui-react-core";
import { Numeric } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterSplineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSplineSeries, _super);
    function ScatterSplineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSplineSeries.$;
        _this.y0 = new ScatterFrame();
        _this.y2 = new ScatterFrame();
        _this.yy = new ScatterFrame();
        return _this;
    }
    ScatterSplineSeries.prototype.bj = function () {
        return new ScatterSplineSeries();
    };
    ScatterSplineSeries.prototype.get_f0 = function () {
        return true;
    };
    ScatterSplineSeries.prototype.cs = function () {
        return new ScatterSplineSeriesView(this);
    };
    ScatterSplineSeries.prototype.zu = function () {
        return true;
    };
    ScatterSplineSeries.prototype.jk = function () {
        if (!isNaN_(this.jj)) {
            return _super.prototype.jk.call(this);
        }
        return Defaults.x;
    };
    ScatterSplineSeries.prototype.q7 = function (a, b, c, d) {
        _super.prototype.q7.call(this, a, b, c, d);
        switch (b) {
            case ScatterSplineSeries.$$p[0]:
                this.rp(false);
                this.qj();
                break;
        }
    };
    ScatterSplineSeries.prototype.b2 = function () {
        if (this.b3 == 0) {
            return 2;
        }
        else {
            return _super.prototype.b2.call(this);
        }
    };
    ScatterSplineSeries.prototype.abd = function (a, b) {
        var _this = this;
        _super.prototype.abd.call(this, a, b);
        a.m.clear();
        a.u.clear();
        var c = b.by;
        var d = b.bx;
        var e = this.getEffectiveViewport1(b);
        var f = this.id * this.id;
        var g = Math.min(this.zf != null ? this.zf.count : 0, this.zg != null ? this.zg.count : 0);
        var h = new ScalerParams(0, c, d, this.yu.d, e);
        var i = ((function () {
            var $ret = new ScalerParams(0, c, d, _this.yu.e, e);
            $ret.b = _this.iy();
            return $ret;
        })());
        var j = function (k) { return _this.yu.a.el(_this.zf.item(k), h); };
        var k = function (l) { return _this.yu.b.el(_this.zg.item(l), i); };
        var l = ((function () {
            var $ret = new Clipper(0, d, false);
            $ret.i = a.m;
            return $ret;
        })());
        for (var m = 0; m < g;) {
            var n = m;
            ++m;
            while (m < g && this.acl(j, k, n, m) < f) {
                ++m;
            }
            if (g > this.z7) {
                l.j(this.acp(j, k, n, m - 1));
            }
            else {
                var o = new OwnedPoint();
                o.c = { $type: Point_$type, x: j(n), y: k(n) };
                o.a = this.dn.item(n);
                if (!a.u.containsKey(o.a)) {
                    a.u.addItem(o.a, o);
                }
            }
        }
        if (g > this.z7) {
            l.i = null;
        }
    };
    ScatterSplineSeries.prototype.acp = function (a, b, c, d) {
        if (c == d) {
            return { $type: Point_$type, x: a(c), y: b(c) };
        }
        var e = 0;
        var f = 0;
        var g = (d - c + 1);
        for (var h = c; h <= d; ++h) {
            e += a(h);
            f += b(h);
        }
        return { $type: Point_$type, x: e / g, y: f / g };
    };
    ScatterSplineSeries.prototype.acl = function (a, b, c, d) {
        var e = a(d) - a(c);
        var f = b(d) - b(c);
        return e * e + f * f;
    };
    ScatterSplineSeries.prototype.get_zo = function () {
        return true;
    };
    ScatterSplineSeries.prototype.o5 = function (a, b) {
        _super.prototype.o5.call(this, a, b);
        var c = typeCast(ScatterSplineSeriesView.$, b);
        c.c9(false);
    };
    ScatterSplineSeries.prototype.abo = function (a, b) {
        this.o5(false, b);
        _super.prototype.abo.call(this, a, b);
        this.abg(a);
        var c = typeCast(ScatterSplineSeriesView.$, b);
        var d = c.dl;
        this.y7.az(this, this.zt(), runOn(this, this.yn));
        var e = false;
        var f = this.y7.b;
        if (f != null) {
            e = true;
        }
        if (e) {
            this.aa9(-1, this.zf.count, b.q);
        }
        this.y7.ad(d, true, false, true, false);
        c.dl.an = new PathGeometry();
        c.dl.an.c = Numeric.h(a.m.count, function (g) { return a.m._inner[g].x; }, function (g) { return a.m._inner[g].y; }, this.acm);
    };
    ScatterSplineSeries.$t = markType(ScatterSplineSeries, 'ScatterSplineSeries', ScatterBase.$);
    ScatterSplineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, ScatterSplineSeries, 'raisePropertyChanged', ['Stiffness:acm:aco', [1, 0.5]]);
    return ScatterSplineSeries;
}(ScatterBase));
export { ScatterSplineSeries };
